Module commonevent

Module commonevent 

Available on crate features commonevent and api-12 only.

Structs

CommonEvent_ErrCode
Defines error codes.
CommonEvent_PublishInfoapi-18
the common event publish information containing content and attributes of the common event
CommonEvent_RcvData
the data of the commonEvent callback
CommonEvent_SubscribeInfo
the information of the subscriber

Functions

OH_CommonEvent_AbortCommonEventapi-18
Abort an ordered event by a subscriber.
OH_CommonEvent_ClearAbortCommonEventapi-18
Clear the aborted flag of an ordered event by a subscriber.
OH_CommonEvent_CreateParametersapi-18
Create a common event publish information.
OH_CommonEvent_CreatePublishInfoapi-18
Create a common event publish information.
OH_CommonEvent_CreateSubscribeInfo
Create subscribe information.
OH_CommonEvent_CreateSubscriber
Create a subscriber.
OH_CommonEvent_DestroyParametersapi-18
Destroy the common event publish information.
OH_CommonEvent_DestroyPublishInfoapi-18
Destroy the common event publish information.
OH_CommonEvent_DestroySubscribeInfo
Destroy the subscribe information.
OH_CommonEvent_DestroySubscriber
Destory the subscriber.
OH_CommonEvent_FinishCommonEventapi-18
Finish an ordered event by a subscriber.
OH_CommonEvent_GetAbortCommonEventapi-18
Check an event by a subscriber whether it is aborted.
OH_CommonEvent_GetBoolArrayFromParameters
Get bool array data from parameters data by key.
OH_CommonEvent_GetBoolFromParameters
Get bool data from parameters data by key.
OH_CommonEvent_GetBundleNameFromRcvData
Get event bundlename from callback data.
OH_CommonEvent_GetCharArrayFromParameters
Get char array data from parameters data by key.
OH_CommonEvent_GetCharFromParameters
Get char data from parameters data by key.
OH_CommonEvent_GetCodeFromRcvData
Get event code from callback data.
OH_CommonEvent_GetCodeFromSubscriberapi-18
Get code from an ordered event by a subscriber.
OH_CommonEvent_GetDataFromSubscriberapi-18
Get data from an ordered event by a subscriber.
OH_CommonEvent_GetDataStrFromRcvData
Get event data from callback data.
OH_CommonEvent_GetDoubleArrayFromParameters
Get double array data from parameters data by key.
OH_CommonEvent_GetDoubleFromParameters
Get double data from parameters data by key.
OH_CommonEvent_GetEventFromRcvData
Get event name from callback data.
OH_CommonEvent_GetIntArrayFromParameters
Get int array data from parameters data by key.
OH_CommonEvent_GetIntFromParameters
Get int data from parameters data by key.
OH_CommonEvent_GetLongArrayFromParameters
Get long array data from parameters data by key.
OH_CommonEvent_GetLongFromParameters
Get long data from parameters data by key.
OH_CommonEvent_GetParametersFromRcvData
Get event parameters data from callback data.
OH_CommonEvent_HasKeyInParameters
Check whether the parameters data contains a key.
OH_CommonEvent_IsOrderedCommonEventapi-18
Check an event by a subscriber whether it is ordered.
OH_CommonEvent_Publishapi-18
Publish a commen event.
OH_CommonEvent_PublishWithInfoapi-18
Publish a commen event with specified publish information.
OH_CommonEvent_SetBoolArrayToParametersapi-18
Set bool array data to parameters data by key.
OH_CommonEvent_SetBoolToParametersapi-18
Set bool data to parameters data by key.
OH_CommonEvent_SetCharArrayToParametersapi-18
Set char array data to parameters data by key.
OH_CommonEvent_SetCharToParametersapi-18
Set char data to parameters data by key.
OH_CommonEvent_SetCodeToSubscriberapi-18
Set code to an ordered event by a subscriber.
OH_CommonEvent_SetDataToSubscriberapi-18
Set data to an ordered event by a subscriber.
OH_CommonEvent_SetDoubleArrayToParametersapi-18
Set double array data to parameters data by key.
OH_CommonEvent_SetDoubleToParametersapi-18
Set double data to parameters data by key.
OH_CommonEvent_SetIntArrayToParametersapi-18
Set int array data to parameters data by key.
OH_CommonEvent_SetIntToParametersapi-18
Set int data to parameters data by key.
OH_CommonEvent_SetLongArrayToParametersapi-18
Set long array data to parameters data by key.
OH_CommonEvent_SetLongToParametersapi-18
Set long data to parameters data by key.
OH_CommonEvent_SetPublishInfoBundleNameapi-18
Set the bundleName of publish information.
OH_CommonEvent_SetPublishInfoCodeapi-18
Set the code of publish information.
OH_CommonEvent_SetPublishInfoDataapi-18
Set the data of publish information.
OH_CommonEvent_SetPublishInfoParametersapi-18
Set the parameters of publish information.
OH_CommonEvent_SetPublishInfoPermissionsapi-18
Set the permissions of publish information.
OH_CommonEvent_SetPublisherBundleName
Set the bundleName of the subscribe information.
OH_CommonEvent_SetPublisherPermission
Set the permission of the subscribe information.
OH_CommonEvent_Subscribe
Subscribe event by a subscriber.
OH_CommonEvent_UnSubscribe
Unsubscribe event by a subscriber.

Type Aliases

CommonEvent_Parameters
The description of the parameters in a common event callback data.
CommonEvent_ReceiveCallback
Common event callback.
CommonEvent_Subscriber
the subscriber of common event