Module commonevent_support

Module commonevent_support 

Available on crate features commonevent and api-12 only.

Constants

COMMON_EVENT_AIRPLANE_MODE_CHANGED
Indicates the common event Action indicating that the airplane mode status of the device changes. Users can register this event to listen to the change of the airplane mode status of the device.
COMMON_EVENT_BATTERY_CHANGED
This commonEvent means when the charging state, level and so on about the battery.
COMMON_EVENT_BATTERY_LOW
This commonEvent means when the device in low battery state.
COMMON_EVENT_BATTERY_OKAY
This commonEvent means when the battery level is an ok state.
COMMON_EVENT_BUNDLE_REMOVED
This commonEvent means when an installed application’s add-on package is removed from the device.
COMMON_EVENT_CALL_STATE_CHANGED
Indicates the action of a common event that the call state has been changed. To subscribe to this protected common event, your application must have the ohos.permission.GET_TELEPHONY_STATE permission. This is a protected common event that can only be sent by system.
COMMON_EVENT_CHARGE_IDLE_MODE_CHANGED
Sent when device’s charge idle mode changed.
COMMON_EVENT_CHARGING
Sent when start charging battery.
COMMON_EVENT_CONNECTIVITY_CHANGE
This commonEvent means when the network connectivityy change.
COMMON_EVENT_DEVICE_IDLE_MODE_CHANGED
Sent when device’s idle mode changed
COMMON_EVENT_DISCHARGING
Sent when stop charging battery.
COMMON_EVENT_DISTRIBUTED_ACCOUNT_LOGOFF
Distributed account logs off.
COMMON_EVENT_DISTRIBUTED_ACCOUNT_LOGOUT
Distributed account logout successfully.
COMMON_EVENT_DISTRIBUTED_ACCOUNT_TOKEN_INVALID
Distributed account is invalid.
COMMON_EVENT_ENTER_HIBERNATEapi-15
This commonEvent means when the device is is about to enter the hibernate mode.
COMMON_EVENT_EXIT_HIBERNATEapi-15
This commonEvent means when the device is exits the hibernate mode.
COMMON_EVENT_HTTP_PROXY_CHANGE
This commonEvent means when the http proxy change.
COMMON_EVENT_LID_STATE_CHANGEDapi-23
This common event means that the state (open or closed) of the laptop lid has changed. This is a protected common event that can only be sent by system.
COMMON_EVENT_LOCALE_CHANGED
The current device’s locale has changed.
COMMON_EVENT_MANAGED_BROWSER_POLICY_CHANGEDapi-15
This common event means that the managed browser policy is changed. This is a protected common event that can only be sent by system.
COMMON_EVENT_MANAGE_PACKAGE_STORAGE
Indicates low memory condition notification acknowledged by user and package management should be started.
COMMON_EVENT_MINORSMODE_OFF
This common event means that minors mode is disabled. This is a protected common event that can only be sent by system.
COMMON_EVENT_MINORSMODE_ON
This common event means that minors mode is enabled. This is a protected common event that can only be sent by system.
COMMON_EVENT_MY_PACKAGE_SUSPENDED
This commonEvent Sent to a package that has been suspended by the system.
COMMON_EVENT_MY_PACKAGE_UNSUSPENDED
Sent to a package that has been un-suspended.
COMMON_EVENT_NETWORK_STATE_CHANGED
Indicates the action of a common event that the network state has been changed. This is a protected common event that can only be sent by system.
COMMON_EVENT_NFC_ACTION_ADAPTER_STATE_CHANGED
Nfc state change.
COMMON_EVENT_NFC_ACTION_RF_FIELD_OFF_DETECTED
Nfc field off detected.
COMMON_EVENT_NFC_ACTION_RF_FIELD_ON_DETECTED
Nfc field on detected.
COMMON_EVENT_PACKAGES_SUSPENDED
This commonEvent means the packages have been suspended.
COMMON_EVENT_PACKAGE_ADDED
This commonEvent means when a new application package is installed on the device.
COMMON_EVENT_PACKAGE_CACHE_CLEARED
This commonEvent means the user has cleared the package cache.
COMMON_EVENT_PACKAGE_CHANGED
This commonEvent means when an existing application package has been changed.
COMMON_EVENT_PACKAGE_DATA_CLEARED
This commonEvent means the user has cleared the package data.
COMMON_EVENT_PACKAGE_FULLY_REMOVED
This commonEvent means when an existing application package is completely removed from the device.
COMMON_EVENT_PACKAGE_REMOVED
This commonEvent means when an existing application package is removed from the device.
COMMON_EVENT_PACKAGE_RESTARTED
This commonEvent means the user has restarted a package, and all of its processes have been killed.
COMMON_EVENT_POWER_CONNECTED
This commonEvent means when the other power is connected to the device.
COMMON_EVENT_POWER_DISCONNECTED
This commonEvent means when the other power is removed from the device.
COMMON_EVENT_POWER_SAVE_MODE_CHANGED
Sent when device’s power save mode changed
COMMON_EVENT_QUICK_FIX_APPLY_RESULT
Indicate the result of quick fix apply. This common event can be triggered only by system.
COMMON_EVENT_QUICK_FIX_REVOKE_RESULT
Indicate the result of quick fix revoke. This common event can be triggered only by system.
COMMON_EVENT_SCREEN_LOCKED
This commonEvent means when the screen is locked.
COMMON_EVENT_SCREEN_OFF
This commonEvent means when the screen is turned off.
COMMON_EVENT_SCREEN_ON
This commonEvent means when the device is awakened and interactive.
COMMON_EVENT_SCREEN_UNLOCKED
This commonEvent means when the screen is unlocked.
COMMON_EVENT_SHUTDOWN
This commonEvent means when the device is shutting down, note: turn off, not sleeping.
COMMON_EVENT_SIGNAL_INFO_CHANGED
Indicates the action of a common event that the signal info has been changed. This is a protected common event that can only be sent by system.
COMMON_EVENT_SIM_STATE_CHANGED
Indicates the action of a common event that the phone SIM card state has changed. This is a protected common event that can only be sent by system.
COMMON_EVENT_SPLIT_SCREEN
sent by the window manager service when the window mode is split.
COMMON_EVENT_TABLET_MODE_CHANGEDapi-23
This common event means that the open and closed state of the stand associated with the tablet mode has changed. This is a protected common event that can only be sent by system.
COMMON_EVENT_THERMAL_LEVEL_CHANGED
This commonEvent means when the thermal state level change
COMMON_EVENT_TIMEZONE_CHANGED
This commonEvent means when the time zone is changed.
COMMON_EVENT_TIME_CHANGED
This commonEvent means when the time is set.
COMMON_EVENT_TIME_TICK
This commonEvent means when the current time is changed.
COMMON_EVENT_USB_DEVICE_ATTACHED
The usb device attached. This is a protected common event that can only be sent by system.
COMMON_EVENT_USB_DEVICE_DETACHED
The usb device detached. This is a protected common event that can only be sent by system.
COMMON_EVENT_USB_PORT_CHANGED
The usb port changed. This is a protected common event that can only be sent by system.
COMMON_EVENT_USB_STATE
The usb state change events. This is a protected common event that can only be sent by system.
COMMON_EVENT_USER_INFO_UPDATED
Indicate the action of a common event that the user information has been updated. This common event can be triggered only by system.
COMMON_EVENT_USER_UNLOCKED
Remind new user of that the service has been unlocked.
COMMON_EVENT_WIFI_AP_STA_JOIN
WIFI ap sta join.
COMMON_EVENT_WIFI_AP_STA_LEAVE
WIFI ap sta join.
COMMON_EVENT_WIFI_CONN_STATE
WIFI connect state.
COMMON_EVENT_WIFI_HOTSPOT_STATE
WIFI hotspot state.
COMMON_EVENT_WIFI_MPLINK_STATE_CHANGE
Indicates Wi-Fi MpLink state notification acknowledged by binding or unbinding MpLink.
COMMON_EVENT_WIFI_P2P_CONN_STATE
Indicates Wi-Fi P2P connection state notification acknowledged by connecting or disconnected P2P.
COMMON_EVENT_WIFI_P2P_CURRENT_DEVICE_STATE_CHANGED
Indicates that the Wi-Fi P2P current device state change.
COMMON_EVENT_WIFI_P2P_GROUP_STATE_CHANGED
Indicates that the Wi-Fi P2P group info is changed.
COMMON_EVENT_WIFI_P2P_PEERS_DISCOVERY_STATE_CHANGED
Indicates that the Wi-Fi P2P discovery state change.
COMMON_EVENT_WIFI_P2P_PEERS_STATE_CHANGED
Indicates that the Wi-Fi P2P peers state change.
COMMON_EVENT_WIFI_P2P_STATE_CHANGED
Indicates that the Wi-Fi P2P state change.
COMMON_EVENT_WIFI_POWER_STATE
WIFI state.
COMMON_EVENT_WIFI_RSSI_VALUE
WIFI RSSI change.
COMMON_EVENT_WIFI_SCAN_FINISHED
WIFI scan results.