Module print

Module print 

Available on crate features print and api-12 only.

Structs

Print_ColorMode
Indicates ColorMode
Print_DefaultValue
Indicates current properties
Print_DiscoveryEvent
Indicate printer discovery events.
Print_DocumentFormat
Indicates the MIME media type of the document.
Print_DuplexMode
Indicates DuplexMode
Print_ErrorCode
Defines error codes.
Print_JobDocAdapterStateapi-13
Indicates the print job doc adapter state.
Print_Margin
Indicates printing margin
Print_OrientationMode
Indicates OrientationMode
Print_PageSize
Indicates paper size info.
Print_PrintAttributesapi-13
Indicates print attributes structure.
Print_PrintDocCallbackapi-13
Indicates print doc state callback structure.
Print_PrintJob
Indicates PrintJob Structure.
Print_PrinterCapability
Indicates printer capabilities.
Print_PrinterEvent
Indicate printer change events.
Print_PrinterInfo
Indicates printer information.
Print_PrinterState
Indicates printer states.
Print_Property
Indicates printer property.
Print_PropertyList
List of printer properties.
Print_Quality
Indicates printing qulity
Print_Rangeapi-13
Indicates print range structure.
Print_Resolution
Indicates print resolution in dpi unit.
Print_StringList
Indicates string list.

Functions

OH_Print_ConnectPrinter
This API connects to the printer using the printer id.
OH_Print_Init
This API checks and pulls up the print service, initializes the print client, and establishes a connection to the print service.
OH_Print_LaunchPrinterManager
This API launches the system’s printer management window.
OH_Print_QueryPrinterInfo
This API queries printer information based on the printer id.
OH_Print_QueryPrinterList
This API queries for a list of added printers.
OH_Print_QueryPrinterProperties
This API queries the corresponding printer property values based on the list of property keywords.
OH_Print_RegisterPrinterChangeListener
This API registers the callback for printer changes.
OH_Print_Release
This API closes the connection from the print service, dissolves the previous callback, and releases the print client resources.
OH_Print_ReleasePrinterInfo
This API frees up the printer infomation memory for the query.
OH_Print_ReleasePrinterList
This API frees up the printer list memory for the query.
OH_Print_ReleasePrinterProperties
This API frees up the property list memory for the query.
OH_Print_RestorePrinterProperties
This API restores printer properties to default settings based on the list of property keywords.
OH_Print_StartPrintByNativeapi-13
This API provide capacity to start print dialog.
OH_Print_StartPrintJob
This API starts initiating a print job.
OH_Print_StartPrinterDiscovery
This API starts discovering printers.
OH_Print_StopPrinterDiscovery
This API stops discovering printers.
OH_Print_UnregisterPrinterChangeListener
This API unregisters the callback for printer changes.
OH_Print_UpdatePrinterProperties
This API sets printer properties based on a list of property key-value pairs.

Type Aliases

Print_OnJobStateChangedapi-13
Print job state callback.
Print_OnStartLayoutWriteapi-13
Print start layout callback.
Print_PrinterChangeCallback
Printer change callback.
Print_PrinterDiscoveryCallback
Printer discovery callback.
Print_WriteResultCallbackapi-13
Write files result callback.