OH_Print_UpdatePrinterProperties

Function OH_Print_UpdatePrinterProperties 

pub unsafe extern "C" fn OH_Print_UpdatePrinterProperties(
    printerId: *const c_char,
    propertyList: *const Print_PropertyList,
) -> Print_ErrorCode
Available on crate features api-12 and print only.
This API sets printer properties based on a list of property key-value pairs.

ohos.permission.PRINT

Arguments

  • printerId - The id of the printer to be set.

  • propertyList - The list of printer property values to be set.

Returns

  • Returns Print_ErrorCode if the execution is successful. [PRINT_ERROR_NO_PERMISSION] The permission ohos.permission.PRINT is needed. [PRINT_ERROR_RPC_FAILURE] Unable to connect to the print service.

Required System Capabilities: SystemCapability.Print.PrintFramework

Available since API-level: 12