OH_Scan_CancelScan

Function OH_Scan_CancelScan 

pub unsafe extern "C" fn OH_Scan_CancelScan(
    scannerId: *const c_char,
) -> i32
Available on crate features scan and api-12 only.
This API allows the scanner to cancel the scan.

ohos.permission.PRINT

Arguments

  • scannerId - This id is used to cancel the scan job for the specified scanner.

Returns

  • [Scan_ERROR_NONE] Indicates that the scanner has successfully canceled the scan job. [SCAN_ERROR_NO_PERMISSION] Indicates have no permission to use this interface. [SCAN_ERROR_INVALID_PARAMETER] Indicates if the pointer is null or the character string is null. [SCAN_ERROR_RPC_FAILURE] Indicates an RPC communication error. [SCAN_ERROR_SERVER_FAILURE] Indicates An error occurs in the scan process.

Required System Capabilities: SystemCapability.Print.PrintFramework

Available since API-level: 12