OH_Scan_Init

Function OH_Scan_Init 

pub unsafe extern "C" fn OH_Scan_Init() -> i32
Available on crate features scan and api-12 only.
This API checks and pulls up the scan service, initializes the scan client, and establishes a connection to the scan service.

ohos.permission.PRINT

Returns

  • [Scan_ERROR_NONE] Indicates the scanning service is successfully started. [SCAN_ERROR_NO_PERMISSION] Indicates have no permission to use this interface. [SCAN_ERROR_RPC_FAILURE] Indicates an RPC communication error. [SCAN_ERROR_SERVER_FAILURE] Indicates An error occurs in the scan process.

Required System Capabilities: SystemCapability.Print.PrintFramework

Available since API-level: 12