#[repr(C)]pub struct Scan_PictureScanProgress {
pub progress: i32,
pub fd: i32,
pub isFinal: bool,
}Available on crate features
scan and api-12 only.Expand description
Indicates the progress of scanning a picture by the scanner.
Available since API-level: 12
Fields
progress: i32Picture progress from 0 to 100.
fd: i32scanner file handle.
isFinal: boolIndicates whether the image is the last scanned image.