Available on crate features
commonevent and api-12 only.Structs
- Common
Event_ ErrCode - Defines error codes.
- Common
Event_ Publish Info api-18 - the common event publish information containing content and attributes of the common event
- Common
Event_ RcvData - the data of the commonEvent callback
- Common
Event_ Subscribe Info - the information of the subscriber
Functions
- OH_
Common ⚠Event_ Abort Common Event api-18 - Abort an ordered event by a subscriber.
- OH_
Common ⚠Event_ Clear Abort Common Event api-18 - Clear the aborted flag of an ordered event by a subscriber.
- OH_
Common ⚠Event_ Create Parameters api-18 - Create a common event publish information.
- OH_
Common ⚠Event_ Create Publish Info api-18 - Create a common event publish information.
- OH_
Common ⚠Event_ Create Subscribe Info - Create subscribe information.
- OH_
Common ⚠Event_ Create Subscriber - Create a subscriber.
- OH_
Common ⚠Event_ Destroy Parameters api-18 - Destroy the common event publish information.
- OH_
Common ⚠Event_ Destroy Publish Info api-18 - Destroy the common event publish information.
- OH_
Common ⚠Event_ Destroy Subscribe Info - Destroy the subscribe information.
- OH_
Common ⚠Event_ Destroy Subscriber - Destory the subscriber.
- OH_
Common ⚠Event_ Finish Common Event api-18 - Finish an ordered event by a subscriber.
- OH_
Common ⚠Event_ GetAbort Common Event api-18 - Check an event by a subscriber whether it is aborted.
- OH_
Common ⚠Event_ GetBool Array From Parameters - Get bool array data from parameters data by key.
- OH_
Common ⚠Event_ GetBool From Parameters - Get bool data from parameters data by key.
- OH_
Common ⚠Event_ GetBundle Name From RcvData - Get event bundlename from callback data.
- OH_
Common ⚠Event_ GetChar Array From Parameters - Get char array data from parameters data by key.
- OH_
Common ⚠Event_ GetChar From Parameters - Get char data from parameters data by key.
- OH_
Common ⚠Event_ GetCode From RcvData - Get event code from callback data.
- OH_
Common ⚠Event_ GetCode From Subscriber api-18 - Get code from an ordered event by a subscriber.
- OH_
Common ⚠Event_ GetData From Subscriber api-18 - Get data from an ordered event by a subscriber.
- OH_
Common ⚠Event_ GetData StrFrom RcvData - Get event data from callback data.
- OH_
Common ⚠Event_ GetDouble Array From Parameters - Get double array data from parameters data by key.
- OH_
Common ⚠Event_ GetDouble From Parameters - Get double data from parameters data by key.
- OH_
Common ⚠Event_ GetEvent From RcvData - Get event name from callback data.
- OH_
Common ⚠Event_ GetInt Array From Parameters - Get int array data from parameters data by key.
- OH_
Common ⚠Event_ GetInt From Parameters - Get int data from parameters data by key.
- OH_
Common ⚠Event_ GetLong Array From Parameters - Get long array data from parameters data by key.
- OH_
Common ⚠Event_ GetLong From Parameters - Get long data from parameters data by key.
- OH_
Common ⚠Event_ GetParameters From RcvData - Get event parameters data from callback data.
- OH_
Common ⚠Event_ HasKey InParameters - Check whether the parameters data contains a key.
- OH_
Common ⚠Event_ IsOrdered Common Event api-18 - Check an event by a subscriber whether it is ordered.
- OH_
Common ⚠Event_ Publish api-18 - Publish a commen event.
- OH_
Common ⚠Event_ Publish With Info api-18 - Publish a commen event with specified publish information.
- OH_
Common ⚠Event_ SetBool Array ToParameters api-18 - Set bool array data to parameters data by key.
- OH_
Common ⚠Event_ SetBool ToParameters api-18 - Set bool data to parameters data by key.
- OH_
Common ⚠Event_ SetChar Array ToParameters api-18 - Set char array data to parameters data by key.
- OH_
Common ⚠Event_ SetChar ToParameters api-18 - Set char data to parameters data by key.
- OH_
Common ⚠Event_ SetCode ToSubscriber api-18 - Set code to an ordered event by a subscriber.
- OH_
Common ⚠Event_ SetData ToSubscriber api-18 - Set data to an ordered event by a subscriber.
- OH_
Common ⚠Event_ SetDouble Array ToParameters api-18 - Set double array data to parameters data by key.
- OH_
Common ⚠Event_ SetDouble ToParameters api-18 - Set double data to parameters data by key.
- OH_
Common ⚠Event_ SetInt Array ToParameters api-18 - Set int array data to parameters data by key.
- OH_
Common ⚠Event_ SetInt ToParameters api-18 - Set int data to parameters data by key.
- OH_
Common ⚠Event_ SetLong Array ToParameters api-18 - Set long array data to parameters data by key.
- OH_
Common ⚠Event_ SetLong ToParameters api-18 - Set long data to parameters data by key.
- OH_
Common ⚠Event_ SetPublish Info Bundle Name api-18 - Set the bundleName of publish information.
- OH_
Common ⚠Event_ SetPublish Info Code api-18 - Set the code of publish information.
- OH_
Common ⚠Event_ SetPublish Info Data api-18 - Set the data of publish information.
- OH_
Common ⚠Event_ SetPublish Info Parameters api-18 - Set the parameters of publish information.
- OH_
Common ⚠Event_ SetPublish Info Permissions api-18 - Set the permissions of publish information.
- OH_
Common ⚠Event_ SetPublisher Bundle Name - Set the bundleName of the subscribe information.
- OH_
Common ⚠Event_ SetPublisher Permission - Set the permission of the subscribe information.
- OH_
Common ⚠Event_ Subscribe - Subscribe event by a subscriber.
- OH_
Common ⚠Event_ UnSubscribe - Unsubscribe event by a subscriber.
Type Aliases
- Common
Event_ Parameters - The description of the parameters in a common event callback data.
- Common
Event_ Receive Callback - Common event callback.
- Common
Event_ Subscriber - the subscriber of common event