Available on crate features
commonevent and api-12 only.Constants
- COMMON_
EVENT_ AIRPLANE_ MODE_ CHANGED - Indicates the common event Action indicating that the airplane mode status of the device changes. Users can register this event to listen to the change of the airplane mode status of the device.
- COMMON_
EVENT_ BATTERY_ CHANGED - This commonEvent means when the charging state, level and so on about the battery.
- COMMON_
EVENT_ BATTERY_ LOW - This commonEvent means when the device in low battery state.
- COMMON_
EVENT_ BATTERY_ OKAY - This commonEvent means when the battery level is an ok state.
- COMMON_
EVENT_ BUNDLE_ REMOVED - This commonEvent means when an installed application’s add-on package is removed from the device.
- COMMON_
EVENT_ CALL_ STATE_ CHANGED - Indicates the action of a common event that the call state has been changed. To subscribe to this protected common event, your application must have the ohos.permission.GET_TELEPHONY_STATE permission. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ CHARGE_ IDLE_ MODE_ CHANGED - Sent when device’s charge idle mode changed.
- COMMON_
EVENT_ CHARGING - Sent when start charging battery.
- COMMON_
EVENT_ CONNECTIVITY_ CHANGE - This commonEvent means when the network connectivityy change.
- COMMON_
EVENT_ DEVICE_ IDLE_ MODE_ CHANGED - Sent when device’s idle mode changed
- COMMON_
EVENT_ DISCHARGING - Sent when stop charging battery.
- COMMON_
EVENT_ DISTRIBUTED_ ACCOUNT_ LOGOFF - Distributed account logs off.
- COMMON_
EVENT_ DISTRIBUTED_ ACCOUNT_ LOGOUT - Distributed account logout successfully.
- COMMON_
EVENT_ DISTRIBUTED_ ACCOUNT_ TOKEN_ INVALID - Distributed account is invalid.
- COMMON_
EVENT_ ENTER_ HIBERNATE api-15 - This commonEvent means when the device is is about to enter the hibernate mode.
- COMMON_
EVENT_ EXIT_ HIBERNATE api-15 - This commonEvent means when the device is exits the hibernate mode.
- COMMON_
EVENT_ HTTP_ PROXY_ CHANGE - This commonEvent means when the http proxy change.
- COMMON_
EVENT_ LID_ STATE_ CHANGED api-23 - This common event means that the state (open or closed) of the laptop lid has changed. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ LOCALE_ CHANGED - The current device’s locale has changed.
- COMMON_
EVENT_ MANAGED_ BROWSER_ POLICY_ CHANGED api-15 - This common event means that the managed browser policy is changed. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ MANAGE_ PACKAGE_ STORAGE - Indicates low memory condition notification acknowledged by user and package management should be started.
- COMMON_
EVENT_ MINORSMODE_ OFF - This common event means that minors mode is disabled. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ MINORSMODE_ ON - This common event means that minors mode is enabled. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ MY_ PACKAGE_ SUSPENDED - This commonEvent Sent to a package that has been suspended by the system.
- COMMON_
EVENT_ MY_ PACKAGE_ UNSUSPENDED - Sent to a package that has been un-suspended.
- COMMON_
EVENT_ NETWORK_ STATE_ CHANGED - Indicates the action of a common event that the network state has been changed. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ NFC_ ACTION_ ADAPTER_ STATE_ CHANGED - Nfc state change.
- COMMON_
EVENT_ NFC_ ACTION_ RF_ FIELD_ OFF_ DETECTED - Nfc field off detected.
- COMMON_
EVENT_ NFC_ ACTION_ RF_ FIELD_ ON_ DETECTED - Nfc field on detected.
- COMMON_
EVENT_ PACKAGES_ SUSPENDED - This commonEvent means the packages have been suspended.
- COMMON_
EVENT_ PACKAGE_ ADDED - This commonEvent means when a new application package is installed on the device.
- COMMON_
EVENT_ PACKAGE_ CACHE_ CLEARED - This commonEvent means the user has cleared the package cache.
- COMMON_
EVENT_ PACKAGE_ CHANGED - This commonEvent means when an existing application package has been changed.
- COMMON_
EVENT_ PACKAGE_ DATA_ CLEARED - This commonEvent means the user has cleared the package data.
- COMMON_
EVENT_ PACKAGE_ FULLY_ REMOVED - This commonEvent means when an existing application package is completely removed from the device.
- COMMON_
EVENT_ PACKAGE_ REMOVED - This commonEvent means when an existing application package is removed from the device.
- COMMON_
EVENT_ PACKAGE_ RESTARTED - This commonEvent means the user has restarted a package, and all of its processes have been killed.
- COMMON_
EVENT_ POWER_ CONNECTED - This commonEvent means when the other power is connected to the device.
- COMMON_
EVENT_ POWER_ DISCONNECTED - This commonEvent means when the other power is removed from the device.
- COMMON_
EVENT_ POWER_ SAVE_ MODE_ CHANGED - Sent when device’s power save mode changed
- COMMON_
EVENT_ QUICK_ FIX_ APPLY_ RESULT - Indicate the result of quick fix apply. This common event can be triggered only by system.
- COMMON_
EVENT_ QUICK_ FIX_ REVOKE_ RESULT - Indicate the result of quick fix revoke. This common event can be triggered only by system.
- COMMON_
EVENT_ SCREEN_ LOCKED - This commonEvent means when the screen is locked.
- COMMON_
EVENT_ SCREEN_ OFF - This commonEvent means when the screen is turned off.
- COMMON_
EVENT_ SCREEN_ ON - This commonEvent means when the device is awakened and interactive.
- COMMON_
EVENT_ SCREEN_ UNLOCKED - This commonEvent means when the screen is unlocked.
- COMMON_
EVENT_ SHUTDOWN - This commonEvent means when the device is shutting down, note: turn off, not sleeping.
- COMMON_
EVENT_ SIGNAL_ INFO_ CHANGED - Indicates the action of a common event that the signal info has been changed. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ SIM_ STATE_ CHANGED - Indicates the action of a common event that the phone SIM card state has changed. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ SPLIT_ SCREEN - sent by the window manager service when the window mode is split.
- COMMON_
EVENT_ TABLET_ MODE_ CHANGED api-23 - This common event means that the open and closed state of the stand associated with the tablet mode has changed. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ THERMAL_ LEVEL_ CHANGED - This commonEvent means when the thermal state level change
- COMMON_
EVENT_ TIMEZONE_ CHANGED - This commonEvent means when the time zone is changed.
- COMMON_
EVENT_ TIME_ CHANGED - This commonEvent means when the time is set.
- COMMON_
EVENT_ TIME_ TICK - This commonEvent means when the current time is changed.
- COMMON_
EVENT_ USB_ DEVICE_ ATTACHED - The usb device attached. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ USB_ DEVICE_ DETACHED - The usb device detached. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ USB_ PORT_ CHANGED - The usb port changed. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ USB_ STATE - The usb state change events. This is a protected common event that can only be sent by system.
- COMMON_
EVENT_ USER_ INFO_ UPDATED - Indicate the action of a common event that the user information has been updated. This common event can be triggered only by system.
- COMMON_
EVENT_ USER_ UNLOCKED - Remind new user of that the service has been unlocked.
- COMMON_
EVENT_ WIFI_ AP_ STA_ JOIN - WIFI ap sta join.
- COMMON_
EVENT_ WIFI_ AP_ STA_ LEAVE - WIFI ap sta join.
- COMMON_
EVENT_ WIFI_ CONN_ STATE - WIFI connect state.
- COMMON_
EVENT_ WIFI_ HOTSPOT_ STATE - WIFI hotspot state.
- COMMON_
EVENT_ WIFI_ MPLINK_ STATE_ CHANGE - Indicates Wi-Fi MpLink state notification acknowledged by binding or unbinding MpLink.
- COMMON_
EVENT_ WIFI_ P2P_ CONN_ STATE - Indicates Wi-Fi P2P connection state notification acknowledged by connecting or disconnected P2P.
- COMMON_
EVENT_ WIFI_ P2P_ CURRENT_ DEVICE_ STATE_ CHANGED - Indicates that the Wi-Fi P2P current device state change.
- COMMON_
EVENT_ WIFI_ P2P_ GROUP_ STATE_ CHANGED - Indicates that the Wi-Fi P2P group info is changed.
- COMMON_
EVENT_ WIFI_ P2P_ PEERS_ DISCOVERY_ STATE_ CHANGED - Indicates that the Wi-Fi P2P discovery state change.
- COMMON_
EVENT_ WIFI_ P2P_ PEERS_ STATE_ CHANGED - Indicates that the Wi-Fi P2P peers state change.
- COMMON_
EVENT_ WIFI_ P2P_ STATE_ CHANGED - Indicates that the Wi-Fi P2P state change.
- COMMON_
EVENT_ WIFI_ POWER_ STATE - WIFI state.
- COMMON_
EVENT_ WIFI_ RSSI_ VALUE - WIFI RSSI change.
- COMMON_
EVENT_ WIFI_ SCAN_ FINISHED - WIFI scan results.