Available on crate features
print and api-12 only.Structs
- Print_
Color Mode - Indicates ColorMode
- Print_
Default Value - Indicates current properties
- Print_
Discovery Event - Indicate printer discovery events.
- Print_
Document Format - Indicates the MIME media type of the document.
- Print_
Duplex Mode - Indicates DuplexMode
- Print_
Error Code - Defines error codes.
- Print_
JobDoc Adapter State api-13 - Indicates the print job doc adapter state.
- Print_
Margin - Indicates printing margin
- Print_
Orientation Mode - Indicates OrientationMode
- Print_
Page Size - Indicates paper size info.
- Print_
Print Attributes api-13 - Indicates print attributes structure.
- Print_
Print DocCallback api-13 - Indicates print doc state callback structure.
- Print_
Print Job - Indicates PrintJob Structure.
- Print_
Printer Capability - Indicates printer capabilities.
- Print_
Printer Event - Indicate printer change events.
- Print_
Printer Info - Indicates printer information.
- Print_
Printer State - Indicates printer states.
- Print_
Property - Indicates printer property.
- Print_
Property List - List of printer properties.
- Print_
Quality - Indicates printing qulity
- Print_
Range api-13 - Indicates print range structure.
- Print_
Resolution - Indicates print resolution in dpi unit.
- Print_
String List - Indicates string list.
Functions
- OH_
Print_ ⚠Connect Printer - This API connects to the printer using the printer id.
- OH_
Print_ ⚠Init - This API checks and pulls up the print service, initializes the print client, and establishes a connection to the print service.
- OH_
Print_ ⚠Launch Printer Manager - This API launches the system’s printer management window.
- OH_
Print_ ⚠Query Printer Info - This API queries printer information based on the printer id.
- OH_
Print_ ⚠Query Printer List - This API queries for a list of added printers.
- OH_
Print_ ⚠Query Printer Properties - This API queries the corresponding printer property values based on the list of property keywords.
- OH_
Print_ ⚠Register Printer Change Listener - This API registers the callback for printer changes.
- OH_
Print_ ⚠Release - This API closes the connection from the print service, dissolves the previous callback, and releases the print client resources.
- OH_
Print_ ⚠Release Printer Info - This API frees up the printer infomation memory for the query.
- OH_
Print_ ⚠Release Printer List - This API frees up the printer list memory for the query.
- OH_
Print_ ⚠Release Printer Properties - This API frees up the property list memory for the query.
- OH_
Print_ ⚠Restore Printer Properties - This API restores printer properties to default settings based on the list of property keywords.
- OH_
Print_ ⚠Start Print ByNative api-13 - This API provide capacity to start print dialog.
- OH_
Print_ ⚠Start Print Job - This API starts initiating a print job.
- OH_
Print_ ⚠Start Printer Discovery - This API starts discovering printers.
- OH_
Print_ ⚠Stop Printer Discovery - This API stops discovering printers.
- OH_
Print_ ⚠Unregister Printer Change Listener - This API unregisters the callback for printer changes.
- OH_
Print_ ⚠Update Printer Properties - This API sets printer properties based on a list of property key-value pairs.
Type Aliases
- Print_
OnJob State Changed api-13 - Print job state callback.
- Print_
OnStart Layout Write api-13 - Print start layout callback.
- Print_
Printer Change Callback - Printer change callback.
- Print_
Printer Discovery Callback - Printer discovery callback.
- Print_
Write Result Callback api-13 - Write files result callback.