pub unsafe extern "C" fn OH_Print_Init() -> Print_ErrorCodeAvailable on crate features
print and api-12 only.Expand description
This API checks and pulls up the print service, initializes the print client, and establishes a connection to the print service.
ohos.permission.PRINT
Returns
- Returns
Print_ErrorCodeif the execution is successful. [PRINT_ERROR_NO_PERMISSION] The permissionohos.permission.PRINTis needed. [PRINT_ERROR_RPC_FAILURE] Unable to connect to the print service. [PRINT_ERROR_SERVER_FAILURE] The cups service cannot be started.
Required System Capabilities: SystemCapability.Print.PrintFramework
Available since API-level: 12