pub unsafe extern "C" fn OH_Print_UpdatePrinterProperties(
printerId: *const c_char,
propertyList: *const Print_PropertyList,
) -> Print_ErrorCodeAvailable on crate features
api-12 and print only.Expand description
This API sets printer properties based on a list of property key-value pairs.
ohos.permission.PRINT
Arguments
-
printerId- The id of the printer to be set. -
propertyList- The list of printer property values to be set.
Returns
- Returns
Print_ErrorCodeif the execution is successful. [PRINT_ERROR_NO_PERMISSION] The permissionohos.permission.PRINTis needed. [PRINT_ERROR_RPC_FAILURE] Unable to connect to the print service.
Required System Capabilities: SystemCapability.Print.PrintFramework
Available since API-level: 12