Available on crate features
scan and api-12 only.Structs
- Scan_
Error Code - Defines error codes.
- Scan_
Picture Scan Progress - Indicates the progress of scanning a picture by the scanner.
- Scan_
Scanner Device - Indicates scanner device information.
- Scan_
Scanner Options - Indicates all parameter options for one scanner.
Functions
- OH_
Scan_ ⚠Cancel Scan - This API allows the scanner to cancel the scan.
- OH_
Scan_ ⚠Close Scanner - This API is used to close the connected scanner device.
- OH_
Scan_ ⚠Exit - This API can be used to exit the scanning service, free the Scan Framework Memory, and unregister the callback for scanner discover.
- OH_
Scan_ ⚠GetPicture Scan Progress - This API can get the progress of the scanner scanning the picture.A non-null value must be passed in, and the scan progress will be written to the structure to which the pointer points.
- OH_
Scan_ ⚠GetScanner Parameter - This API can be used to get a list of options that can be set by the scanner.
The returned struct pointer points to memory that is automatically freed when
OH_Scan_Exit, and only one copy will be stored in memory for each model. - OH_
Scan_ ⚠Init - This API checks and pulls up the scan service, initializes the scan client, and establishes a connection to the scan service.
- OH_
Scan_ ⚠Open Scanner - This API connects to scanner devices.
- OH_
Scan_ ⚠SetScanner Parameter - This API can be used to set one of the scanner’s option parameters.
The option and value passed in are obtained from
OH_Scan_GetScannerParameter. - OH_
Scan_ ⚠Start Scan - This API allows the scanner to start scanning.
- OH_
Scan_ ⚠Start Scanner Discovery - This API starts discovering scanners, Register a callback to handle discovered scanner devices.
Type Aliases
- Scan_
Scanner Discovery Callback - Scanner devices discovery callback, register by
OH_Scan_StartScannerDiscovery. The memory to which the pointer points will be released when the callback function ends.