pub unsafe extern "C" fn OH_Scan_Exit() -> i32Available on crate features
scan and api-12 only.Expand description
This API can be used to exit the scanning service, free the Scan Framework Memory, and unregister the callback for scanner discover.
ohos.permission.PRINT
Returns
- [
Scan_ERROR_NONE] Indicates the scan service exit successfully. [SCAN_ERROR_NO_PERMISSION] Indicates have no permission to use this interface. [SCAN_ERROR_RPC_FAILURE] Indicates an RPC communication error. [SCAN_ERROR_SERVER_FAILURE] Indicates An error occurs in the scan process.
Required System Capabilities: SystemCapability.Print.PrintFramework
Available since API-level: 12