pub unsafe extern "C" fn OH_Scan_StartScan(
scannerId: *const c_char,
batchMode: bool,
) -> i32Available on crate features
scan and api-12 only.Expand description
This API allows the scanner to start scanning.
ohos.permission.PRINT
Arguments
-
scannerId- This id is used to start the scan job for the specified scanner. -
batchMode- Whether to start the scanner in batch mode.
Returns
- [
Scan_ERROR_NONE] Indicates that the scanner has successfully canceled the scan job. [SCAN_ERROR_NO_PERMISSION] Indicates have no permission to use this interface. [SCAN_ERROR_RPC_FAILURE] Indicates an RPC communication error. [SCAN_ERROR_SERVER_FAILURE] Indicates An error occurs in the scan process. [SCAN_ERROR_JAMMED] Indicates the document feeder is jammed. [SCAN_ERROR_NO_DOCS] Indicates the document feeder is out of documents. [SCAN_ERROR_COVER_OPEN] Indicates the scanner cover is open. [SCAN_ERROR_IO_ERROR] Indicates an error occurred while communicating with the device. [SCAN_ERROR_NO_MEMORY] Indicates an insufficent amount of memory is available. [SCAN_ERROR_INVALID_PARAMETER] Indicates that the input parameter is invalid. [SCAN_ERROR_DEVICE_BUSY] Indicates the device is busy, the operation should be retried later.
Required System Capabilities: SystemCapability.Print.PrintFramework
Available since API-level: 12